==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/controlplane/v1alpha1/PodNetworkConnectivityCheckSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.controlplane.v1alpha1;

import io.fabric8.openshift.api.model.SecretNameReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl;
import io.fabric8.openshift.api.model.SecretNameReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PodNetworkConnectivityCheckSpecFluentImpl<A extends io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent<A>{
  public PodNetworkConnectivityCheckSpecFluentImpl() {
  }
  public PodNetworkConnectivityCheckSpecFluentImpl(io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpec instance) {
    this.withSourcePod(instance.getSourcePod()); 
    this.withTargetEndpoint(instance.getTargetEndpoint()); 
    this.withTlsClientCert(instance.getTlsClientCert()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String sourcePod;
  private java.lang.String targetEndpoint;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder tlsClientCert;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getSourcePod() {
    return this.sourcePod;
  }
  public A withSourcePod(java.lang.String sourcePod) {
    this.sourcePod=sourcePod; return (A) this;
  }
  public java.lang.Boolean hasSourcePod() {
    return this.sourcePod != null;
  }
  
  /**
   * Method is deprecated. use withSourcePod instead.
   */
  @java.lang.Deprecated
  public A withNewSourcePod(java.lang.String arg0) {
    return (A)withSourcePod(new String(arg0));
  }
  public java.lang.String getTargetEndpoint() {
    return this.targetEndpoint;
  }
  public A withTargetEndpoint(java.lang.String targetEndpoint) {
    this.targetEndpoint=targetEndpoint; return (A) this;
  }
  public java.lang.Boolean hasTargetEndpoint() {
    return this.targetEndpoint != null;
  }
  
  /**
   * Method is deprecated. use withTargetEndpoint instead.
   */
  @java.lang.Deprecated
  public A withNewTargetEndpoint(java.lang.String arg0) {
    return (A)withTargetEndpoint(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTlsClientCert instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientCert() {
    return this.tlsClientCert!=null?this.tlsClientCert.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientCert() {
    return this.tlsClientCert!=null?this.tlsClientCert.build():null;
  }
  public A withTlsClientCert(io.fabric8.openshift.api.model.SecretNameReference tlsClientCert) {
    _visitables.get("tlsClientCert").remove(this.tlsClientCert);
    if (tlsClientCert!=null){ this.tlsClientCert= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(tlsClientCert); _visitables.get("tlsClientCert").add(this.tlsClientCert);} return (A) this;
  }
  public java.lang.Boolean hasTlsClientCert() {
    return this.tlsClientCert != null;
  }
  public A withNewTlsClientCert(java.lang.String name) {
    return (A)withTlsClientCert(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> withNewTlsClientCert() {
    return new io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluentImpl.TlsClientCertNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> withNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluentImpl.TlsClientCertNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> editTlsClientCert() {
    return withNewTlsClientCertLike(getTlsClientCert());
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> editOrNewTlsClientCert() {
    return withNewTlsClientCertLike(getTlsClientCert() != null ? getTlsClientCert(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> editOrNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewTlsClientCertLike(getTlsClientCert() != null ? getTlsClientCert(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodNetworkConnectivityCheckSpecFluentImpl that = (PodNetworkConnectivityCheckSpecFluentImpl) o;
    if (sourcePod != null ? !sourcePod.equals(that.sourcePod) :that.sourcePod != null) return false;
    if (targetEndpoint != null ? !targetEndpoint.equals(that.targetEndpoint) :that.targetEndpoint != null) return false;
    if (tlsClientCert != null ? !tlsClientCert.equals(that.tlsClientCert) :that.tlsClientCert != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(sourcePod,  targetEndpoint,  tlsClientCert,  additionalProperties,  super.hashCode());
  }
  public class TlsClientCertNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<N>> implements io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsClientCertNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    TlsClientCertNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) PodNetworkConnectivityCheckSpecFluentImpl.this.withTlsClientCert(builder.build());
    }
    public N endTlsClientCert() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/controlplane/v1alpha1/PodNetworkConnectivityCheckSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.controlplane.v1alpha1;

import io.fabric8.openshift.api.model.SecretNameReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl;
import io.fabric8.openshift.api.model.SecretNameReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PodNetworkConnectivityCheckSpecFluentImpl<A extends io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent<A>{
  public PodNetworkConnectivityCheckSpecFluentImpl() {
  }
  public PodNetworkConnectivityCheckSpecFluentImpl(io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpec instance) {
    this.withSourcePod(instance.getSourcePod()); 
    this.withTargetEndpoint(instance.getTargetEndpoint()); 
    this.withTlsClientCert(instance.getTlsClientCert()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String sourcePod;
  private java.lang.String targetEndpoint;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder tlsClientCert;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getSourcePod() {
    return this.sourcePod;
  }
  public A withSourcePod(java.lang.String sourcePod) {
    this.sourcePod=sourcePod; return (A) this;
  }
  public java.lang.Boolean hasSourcePod() {
    return this.sourcePod != null;
  }
  
  /**
   * Method is deprecated. use withSourcePod instead.
   */
  @java.lang.Deprecated
  public A withNewSourcePod(java.lang.String arg0) {
    return (A)withSourcePod(new String(arg0));
  }
  public java.lang.String getTargetEndpoint() {
    return this.targetEndpoint;
  }
  public A withTargetEndpoint(java.lang.String targetEndpoint) {
    this.targetEndpoint=targetEndpoint; return (A) this;
  }
  public java.lang.Boolean hasTargetEndpoint() {
    return this.targetEndpoint != null;
  }
  
  /**
   * Method is deprecated. use withTargetEndpoint instead.
   */
  @java.lang.Deprecated
  public A withNewTargetEndpoint(java.lang.String arg0) {
    return (A)withTargetEndpoint(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTlsClientCert instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientCert() {
    return this.tlsClientCert!=null?this.tlsClientCert.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientCert() {
    return this.tlsClientCert!=null?this.tlsClientCert.build():null;
  }
  public A withTlsClientCert(io.fabric8.openshift.api.model.SecretNameReference tlsClientCert) {
    _visitables.get("tlsClientCert").remove(this.tlsClientCert);
    if (tlsClientCert!=null){ this.tlsClientCert= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(tlsClientCert); _visitables.get("tlsClientCert").add(this.tlsClientCert);} return (A) this;
  }
  public java.lang.Boolean hasTlsClientCert() {
    return this.tlsClientCert != null;
  }
  public A withNewTlsClientCert(java.lang.String name) {
    return (A)withTlsClientCert(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> withNewTlsClientCert() {
    return new io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluentImpl.TlsClientCertNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> withNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluentImpl.TlsClientCertNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> editTlsClientCert() {
    return withNewTlsClientCertLike(getTlsClientCert());
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> editOrNewTlsClientCert() {
    return withNewTlsClientCertLike(getTlsClientCert() != null ? getTlsClientCert(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<A> editOrNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewTlsClientCertLike(getTlsClientCert() != null ? getTlsClientCert(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodNetworkConnectivityCheckSpecFluentImpl that = (PodNetworkConnectivityCheckSpecFluentImpl) o;
    if (sourcePod != null ? !sourcePod.equals(that.sourcePod) :that.sourcePod != null) return false;
    if (targetEndpoint != null ? !targetEndpoint.equals(that.targetEndpoint) :that.targetEndpoint != null) return false;
    if (tlsClientCert != null ? !tlsClientCert.equals(that.tlsClientCert) :that.tlsClientCert != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(sourcePod,  targetEndpoint,  tlsClientCert,  additionalProperties,  super.hashCode());
  }
  public class TlsClientCertNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<N>> implements io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.PodNetworkConnectivityCheckSpecFluent.TlsClientCertNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TlsClientCertNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    TlsClientCertNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) PodNetworkConnectivityCheckSpecFluentImpl.this.withTlsClientCert(builder.build());
    }
    public N endTlsClientCert() {
      return and();
    }
    
  }
  
}
